# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllProjectsResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_name': 'str',
        'project_id': 'str',
        'created_date': 'str',
        'created_recruiter_info': 'GetAllProjectsResponseCreatedRecruiterInfo',
        'workflow_id': 'str',
        'workflow_name': 'str'
    }

    attribute_map = {
        'project_name': 'projectName',
        'project_id': 'projectId',
        'created_date': 'createdDate',
        'created_recruiter_info': 'createdRecruiterInfo',
        'workflow_id': 'workflowId',
        'workflow_name': 'workflowName'
    }

    def __init__(self, project_name=None, project_id=None, created_date=None, created_recruiter_info=None, workflow_id=None, workflow_name=None):  # noqa: E501
        """GetAllProjectsResponseData - a model defined in Swagger"""  # noqa: E501
        self._project_name = None
        self._project_id = None
        self._created_date = None
        self._created_recruiter_info = None
        self._workflow_id = None
        self._workflow_name = None
        self.discriminator = None
        self.project_name = project_name
        self.project_id = project_id
        self.created_date = created_date
        self.created_recruiter_info = created_recruiter_info
        self.workflow_id = workflow_id
        self.workflow_name = workflow_name

    @property
    def project_name(self):
        """Gets the project_name of this GetAllProjectsResponseData.  # noqa: E501

        The name of the project.  # noqa: E501

        :return: The project_name of this GetAllProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this GetAllProjectsResponseData.

        The name of the project.  # noqa: E501

        :param project_name: The project_name of this GetAllProjectsResponseData.  # noqa: E501
        :type: str
        """
        if project_name is None:
            raise ValueError("Invalid value for `project_name`, must not be `None`")  # noqa: E501

        self._project_name = project_name

    @property
    def project_id(self):
        """Gets the project_id of this GetAllProjectsResponseData.  # noqa: E501

        The unique identifier for the project.  # noqa: E501

        :return: The project_id of this GetAllProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this GetAllProjectsResponseData.

        The unique identifier for the project.  # noqa: E501

        :param project_id: The project_id of this GetAllProjectsResponseData.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def created_date(self):
        """Gets the created_date of this GetAllProjectsResponseData.  # noqa: E501

        The date when the project was created.  # noqa: E501

        :return: The created_date of this GetAllProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetAllProjectsResponseData.

        The date when the project was created.  # noqa: E501

        :param created_date: The created_date of this GetAllProjectsResponseData.  # noqa: E501
        :type: str
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def created_recruiter_info(self):
        """Gets the created_recruiter_info of this GetAllProjectsResponseData.  # noqa: E501


        :return: The created_recruiter_info of this GetAllProjectsResponseData.  # noqa: E501
        :rtype: GetAllProjectsResponseCreatedRecruiterInfo
        """
        return self._created_recruiter_info

    @created_recruiter_info.setter
    def created_recruiter_info(self, created_recruiter_info):
        """Sets the created_recruiter_info of this GetAllProjectsResponseData.


        :param created_recruiter_info: The created_recruiter_info of this GetAllProjectsResponseData.  # noqa: E501
        :type: GetAllProjectsResponseCreatedRecruiterInfo
        """
        if created_recruiter_info is None:
            raise ValueError("Invalid value for `created_recruiter_info`, must not be `None`")  # noqa: E501

        self._created_recruiter_info = created_recruiter_info

    @property
    def workflow_id(self):
        """Gets the workflow_id of this GetAllProjectsResponseData.  # noqa: E501

        The unique identifier for the workflow associated with the project.  # noqa: E501

        :return: The workflow_id of this GetAllProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this GetAllProjectsResponseData.

        The unique identifier for the workflow associated with the project.  # noqa: E501

        :param workflow_id: The workflow_id of this GetAllProjectsResponseData.  # noqa: E501
        :type: str
        """
        if workflow_id is None:
            raise ValueError("Invalid value for `workflow_id`, must not be `None`")  # noqa: E501

        self._workflow_id = workflow_id

    @property
    def workflow_name(self):
        """Gets the workflow_name of this GetAllProjectsResponseData.  # noqa: E501

        The name of the workflow associated with the project.  # noqa: E501

        :return: The workflow_name of this GetAllProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._workflow_name

    @workflow_name.setter
    def workflow_name(self, workflow_name):
        """Sets the workflow_name of this GetAllProjectsResponseData.

        The name of the workflow associated with the project.  # noqa: E501

        :param workflow_name: The workflow_name of this GetAllProjectsResponseData.  # noqa: E501
        :type: str
        """
        if workflow_name is None:
            raise ValueError("Invalid value for `workflow_name`, must not be `None`")  # noqa: E501

        self._workflow_name = workflow_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllProjectsResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllProjectsResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobActivities(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'message': 'str',
        'timestamp': 'str',
        'pagination': 'JobActivitiesPagination',
        'data': 'list[JobActivitiesData]'
    }

    attribute_map = {
        'status': 'status',
        'message': 'message',
        'timestamp': 'timestamp',
        'pagination': 'pagination',
        'data': 'data'
    }

    def __init__(self, status=None, message=None, timestamp=None, pagination=None, data=None):  # noqa: E501
        """JobActivities - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._message = None
        self._timestamp = None
        self._pagination = None
        self._data = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if message is not None:
            self.message = message
        if timestamp is not None:
            self.timestamp = timestamp
        if pagination is not None:
            self.pagination = pagination
        if data is not None:
            self.data = data

    @property
    def status(self):
        """Gets the status of this JobActivities.  # noqa: E501

        The overall status of the job activities response.  # noqa: E501

        :return: The status of this JobActivities.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JobActivities.

        The overall status of the job activities response.  # noqa: E501

        :param status: The status of this JobActivities.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def message(self):
        """Gets the message of this JobActivities.  # noqa: E501

        A message related to the job activities.  # noqa: E501

        :return: The message of this JobActivities.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this JobActivities.

        A message related to the job activities.  # noqa: E501

        :param message: The message of this JobActivities.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def timestamp(self):
        """Gets the timestamp of this JobActivities.  # noqa: E501

        Timestamp indicating when the response was generated.  # noqa: E501

        :return: The timestamp of this JobActivities.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this JobActivities.

        Timestamp indicating when the response was generated.  # noqa: E501

        :param timestamp: The timestamp of this JobActivities.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def pagination(self):
        """Gets the pagination of this JobActivities.  # noqa: E501


        :return: The pagination of this JobActivities.  # noqa: E501
        :rtype: JobActivitiesPagination
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination):
        """Sets the pagination of this JobActivities.


        :param pagination: The pagination of this JobActivities.  # noqa: E501
        :type: JobActivitiesPagination
        """

        self._pagination = pagination

    @property
    def data(self):
        """Gets the data of this JobActivities.  # noqa: E501

        Array of job activity data.  # noqa: E501

        :return: The data of this JobActivities.  # noqa: E501
        :rtype: list[JobActivitiesData]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this JobActivities.

        Array of job activity data.  # noqa: E501

        :param data: The data of this JobActivities.  # noqa: E501
        :type: list[JobActivitiesData]
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobActivities, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobActivities):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobsync-api

    Job Sync enables the user to manage jobs (view, create, update and delete jobs) in the Phenom database directly from the ATS, with the updates reflected on the career site.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: shravan.malla@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class JobsApi(object):
    base_path = "/jobs-api"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def delete_job_by_reference_id(self, reference_id, **kwargs):  # noqa: E501
        """Delete Job By Reference Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_job_by_reference_id(reference_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reference_id: (required)
        :return: JobSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_job_by_reference_id_with_http_info(reference_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_job_by_reference_id_with_http_info(reference_id, **kwargs)  # noqa: E501
            return data

    def delete_job_by_reference_id_with_http_info(self, reference_id, **kwargs):  # noqa: E501
        """Delete Job By Reference Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_job_by_reference_id_with_http_info(reference_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reference_id: (required)
        :return: JobSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reference_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_job_by_reference_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reference_id' is set
        if ('reference_id' not in params or
                params['reference_id'] is None):
            raise ValueError("Missing the required parameter `reference_id` when calling `delete_job_by_reference_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'reference_id' in params:
            path_params['referenceId'] = params['reference_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{referenceId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_closed_jobs(self, **kwargs):  # noqa: E501
        """Get Closed Jobs By Search Params  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_closed_jobs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id:
        :param str locale:
        :param str category:
        :param str site_type:
        :param str offset:
        :param str limit:
        :return: JobsListSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_closed_jobs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_closed_jobs_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_closed_jobs_with_http_info(self, **kwargs):  # noqa: E501
        """Get Closed Jobs By Search Params  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_closed_jobs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id:
        :param str locale:
        :param str category:
        :param str site_type:
        :param str offset:
        :param str limit:
        :return: JobsListSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id', 'locale', 'category', 'site_type', 'offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_closed_jobs" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'job_id' in params:
            query_params.append(('jobId', params['job_id']))  # noqa: E501
        if 'locale' in params:
            query_params.append(('locale', params['locale']))  # noqa: E501
        if 'category' in params:
            query_params.append(('category', params['category']))  # noqa: E501
        if 'site_type' in params:
            query_params.append(('siteType', params['site_type']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/closedJobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobsListSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_job_by_reference_id(self, reference_id, **kwargs):  # noqa: E501
        """Get Job By Reference Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_by_reference_id(reference_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reference_id: (required)
        :return: JobSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_job_by_reference_id_with_http_info(reference_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_job_by_reference_id_with_http_info(reference_id, **kwargs)  # noqa: E501
            return data

    def get_job_by_reference_id_with_http_info(self, reference_id, **kwargs):  # noqa: E501
        """Get Job By Reference Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_by_reference_id_with_http_info(reference_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reference_id: (required)
        :return: JobSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reference_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_job_by_reference_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reference_id' is set
        if ('reference_id' not in params or
                params['reference_id'] is None):
            raise ValueError("Missing the required parameter `reference_id` when calling `get_job_by_reference_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'reference_id' in params:
            path_params['referenceId'] = params['reference_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{referenceId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_jobs(self, **kwargs):  # noqa: E501
        """Get Jobs By Search Params  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_jobs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id:
        :param str locale:
        :param str category:
        :param str site_type:
        :param str offset:
        :param str limit:
        :return: JobsListSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_jobs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_jobs_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_jobs_with_http_info(self, **kwargs):  # noqa: E501
        """Get Jobs By Search Params  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_jobs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id:
        :param str locale:
        :param str category:
        :param str site_type:
        :param str offset:
        :param str limit:
        :return: JobsListSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id', 'locale', 'category', 'site_type', 'offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_jobs" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'job_id' in params:
            query_params.append(('jobId', params['job_id']))  # noqa: E501
        if 'locale' in params:
            query_params.append(('locale', params['locale']))  # noqa: E501
        if 'category' in params:
            query_params.append(('category', params['category']))  # noqa: E501
        if 'site_type' in params:
            query_params.append(('siteType', params['site_type']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobsListSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_job_by_reference_id(self, body, reference_id, **kwargs):  # noqa: E501
        """Update Job By Reference Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_job_by_reference_id(body, reference_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PatchPayload body: (required)
        :param str reference_id: (required)
        :return: JobSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.patch_job_by_reference_id_with_http_info(body, reference_id, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_job_by_reference_id_with_http_info(body, reference_id, **kwargs)  # noqa: E501
            return data

    def patch_job_by_reference_id_with_http_info(self, body, reference_id, **kwargs):  # noqa: E501
        """Update Job By Reference Id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_job_by_reference_id_with_http_info(body, reference_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PatchPayload body: (required)
        :param str reference_id: (required)
        :return: JobSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'reference_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_job_by_reference_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `patch_job_by_reference_id`")  # noqa: E501
        # verify the required parameter 'reference_id' is set
        if ('reference_id' not in params or
                params['reference_id'] is None):
            raise ValueError("Missing the required parameter `reference_id` when calling `patch_job_by_reference_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'reference_id' in params:
            path_params['referenceId'] = params['reference_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{referenceId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_jobs(self, body, **kwargs):  # noqa: E501
        """Create Job  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_jobs(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostPayload body: (required)
        :return: JobSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_jobs_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_jobs_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_jobs_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create Job  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_jobs_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PostPayload body: (required)
        :return: JobSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_jobs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_jobs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    employees-api-careerpath

    The Employee upskill APIs are related to the career pathing that an employee can use them for upskilling in an organisation.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.employeescareerpath.models.bad_request import BadRequest
from phenom.api.employeescareerpath.models.career_path_data import CareerPathData
from phenom.api.employeescareerpath.models.career_path_success_response import CareerPathSuccessResponse
from phenom.api.employeescareerpath.models.career_path_success_response_with_data import CareerPathSuccessResponseWithData
from phenom.api.employeescareerpath.models.create_career_path import CreateCareerPath
from phenom.api.employeescareerpath.models.current_job_profile import CurrentJobProfile
from phenom.api.employeescareerpath.models.empty import Empty
from phenom.api.employeescareerpath.models.error_response import ErrorResponse
from phenom.api.employeescareerpath.models.path_item import PathItem
from phenom.api.employeescareerpath.models.update_career_path import UpdateCareerPath



# coding: utf-8

"""
    employees-api-referral

    The employee referral APIs are used to refer, track and recommend jobs to external candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Questionnaire(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'questionnaire': 'object',
        'show_personal_message': 'bool',
        'message': 'str'
    }

    attribute_map = {
        'questionnaire': 'questionnaire',
        'show_personal_message': 'showPersonalMessage',
        'message': 'message'
    }

    def __init__(self, questionnaire=None, show_personal_message=True, message='Hello Friend! I hope this jobs suits your skill set'):  # noqa: E501
        """Questionnaire - a model defined in Swagger"""  # noqa: E501
        self._questionnaire = None
        self._show_personal_message = None
        self._message = None
        self.discriminator = None
        if questionnaire is not None:
            self.questionnaire = questionnaire
        if show_personal_message is not None:
            self.show_personal_message = show_personal_message
        if message is not None:
            self.message = message

    @property
    def questionnaire(self):
        """Gets the questionnaire of this Questionnaire.  # noqa: E501

        Questionnaire to the candidate which is used while making a referral.  # noqa: E501

        :return: The questionnaire of this Questionnaire.  # noqa: E501
        :rtype: object
        """
        return self._questionnaire

    @questionnaire.setter
    def questionnaire(self, questionnaire):
        """Sets the questionnaire of this Questionnaire.

        Questionnaire to the candidate which is used while making a referral.  # noqa: E501

        :param questionnaire: The questionnaire of this Questionnaire.  # noqa: E501
        :type: object
        """

        self._questionnaire = questionnaire

    @property
    def show_personal_message(self):
        """Gets the show_personal_message of this Questionnaire.  # noqa: E501

        Flag whether to give personal message field to employee or not while making a referral.  # noqa: E501

        :return: The show_personal_message of this Questionnaire.  # noqa: E501
        :rtype: bool
        """
        return self._show_personal_message

    @show_personal_message.setter
    def show_personal_message(self, show_personal_message):
        """Sets the show_personal_message of this Questionnaire.

        Flag whether to give personal message field to employee or not while making a referral.  # noqa: E501

        :param show_personal_message: The show_personal_message of this Questionnaire.  # noqa: E501
        :type: bool
        """

        self._show_personal_message = show_personal_message

    @property
    def message(self):
        """Gets the message of this Questionnaire.  # noqa: E501

        Default message to show when personal message flag is enabled.  # noqa: E501

        :return: The message of this Questionnaire.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this Questionnaire.

        Default message to show when personal message flag is enabled.  # noqa: E501

        :param message: The message of this Questionnaire.  # noqa: E501
        :type: str
        """

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Questionnaire, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Questionnaire):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.prediction.prediction_api import PredictionApi

class Prediction(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def prediction_api(self):
        return PredictionApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class LeadsApi(object):
    base_path = "/candidates-api/applications"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def assign_candidates_to_job(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Assign Candidates To Job  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_candidates_to_job(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssignCandidatesToJobRequest body: Assign multiple candidates to job (required)
        :param str x_ph_userid: (required)
        :return: AssignCandidatesToJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assign_candidates_to_job_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.assign_candidates_to_job_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def assign_candidates_to_job_with_http_info(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Assign Candidates To Job  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_candidates_to_job_with_http_info(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssignCandidatesToJobRequest body: Assign multiple candidates to job (required)
        :param str x_ph_userid: (required)
        :return: AssignCandidatesToJobResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assign_candidates_to_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `assign_candidates_to_job`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `assign_candidates_to_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/assign-candidates-to-job', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssignCandidatesToJobResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmailCampaignOptInHistoryDetailsPageable(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sort': 'EmailCampaignOptInHistoryDetailsPageableSort',
        'page_number': 'int',
        'offset': 'int',
        'page_size': 'int',
        'paged': 'bool',
        'unpaged': 'bool'
    }

    attribute_map = {
        'sort': 'sort',
        'page_number': 'pageNumber',
        'offset': 'offset',
        'page_size': 'pageSize',
        'paged': 'paged',
        'unpaged': 'unpaged'
    }

    def __init__(self, sort=None, page_number=None, offset=None, page_size=None, paged=None, unpaged=None):  # noqa: E501
        """EmailCampaignOptInHistoryDetailsPageable - a model defined in Swagger"""  # noqa: E501
        self._sort = None
        self._page_number = None
        self._offset = None
        self._page_size = None
        self._paged = None
        self._unpaged = None
        self.discriminator = None
        self.sort = sort
        self.page_number = page_number
        self.offset = offset
        self.page_size = page_size
        self.paged = paged
        self.unpaged = unpaged

    @property
    def sort(self):
        """Gets the sort of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501


        :return: The sort of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :rtype: EmailCampaignOptInHistoryDetailsPageableSort
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this EmailCampaignOptInHistoryDetailsPageable.


        :param sort: The sort of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :type: EmailCampaignOptInHistoryDetailsPageableSort
        """
        if sort is None:
            raise ValueError("Invalid value for `sort`, must not be `None`")  # noqa: E501

        self._sort = sort

    @property
    def page_number(self):
        """Gets the page_number of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501

        The current page number.  # noqa: E501

        :return: The page_number of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this EmailCampaignOptInHistoryDetailsPageable.

        The current page number.  # noqa: E501

        :param page_number: The page_number of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :type: int
        """
        if page_number is None:
            raise ValueError("Invalid value for `page_number`, must not be `None`")  # noqa: E501

        self._page_number = page_number

    @property
    def offset(self):
        """Gets the offset of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501

        The offset of the current page.  # noqa: E501

        :return: The offset of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this EmailCampaignOptInHistoryDetailsPageable.

        The offset of the current page.  # noqa: E501

        :param offset: The offset of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :type: int
        """
        if offset is None:
            raise ValueError("Invalid value for `offset`, must not be `None`")  # noqa: E501

        self._offset = offset

    @property
    def page_size(self):
        """Gets the page_size of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501

        The size of each page in the paginated list.  # noqa: E501

        :return: The page_size of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this EmailCampaignOptInHistoryDetailsPageable.

        The size of each page in the paginated list.  # noqa: E501

        :param page_size: The page_size of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :type: int
        """
        if page_size is None:
            raise ValueError("Invalid value for `page_size`, must not be `None`")  # noqa: E501

        self._page_size = page_size

    @property
    def paged(self):
        """Gets the paged of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501

        Indicates whether the list is paginated.  # noqa: E501

        :return: The paged of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :rtype: bool
        """
        return self._paged

    @paged.setter
    def paged(self, paged):
        """Sets the paged of this EmailCampaignOptInHistoryDetailsPageable.

        Indicates whether the list is paginated.  # noqa: E501

        :param paged: The paged of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :type: bool
        """
        if paged is None:
            raise ValueError("Invalid value for `paged`, must not be `None`")  # noqa: E501

        self._paged = paged

    @property
    def unpaged(self):
        """Gets the unpaged of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501

        Indicates whether the list is unpaged.  # noqa: E501

        :return: The unpaged of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :rtype: bool
        """
        return self._unpaged

    @unpaged.setter
    def unpaged(self, unpaged):
        """Sets the unpaged of this EmailCampaignOptInHistoryDetailsPageable.

        Indicates whether the list is unpaged.  # noqa: E501

        :param unpaged: The unpaged of this EmailCampaignOptInHistoryDetailsPageable.  # noqa: E501
        :type: bool
        """
        if unpaged is None:
            raise ValueError("Invalid value for `unpaged`, must not be `None`")  # noqa: E501

        self._unpaged = unpaged

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailCampaignOptInHistoryDetailsPageable, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailCampaignOptInHistoryDetailsPageable):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobs-activities-api

    These API's allows you to perform activities on Jobs  # noqa: E501

    OpenAPI spec version: 1.0.3
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateJobNoteRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tagged_recruiters': 'list[str]',
        'entity_type': 'str',
        'note_text': 'str',
        'as_private': 'bool'
    }

    attribute_map = {
        'tagged_recruiters': 'taggedRecruiters',
        'entity_type': 'entityType',
        'note_text': 'noteText',
        'as_private': 'asPrivate'
    }

    def __init__(self, tagged_recruiters=None, entity_type=None, note_text=None, as_private=None):  # noqa: E501
        """CreateJobNoteRequest - a model defined in Swagger"""  # noqa: E501
        self._tagged_recruiters = None
        self._entity_type = None
        self._note_text = None
        self._as_private = None
        self.discriminator = None
        self.tagged_recruiters = tagged_recruiters
        self.entity_type = entity_type
        self.note_text = note_text
        self.as_private = as_private

    @property
    def tagged_recruiters(self):
        """Gets the tagged_recruiters of this CreateJobNoteRequest.  # noqa: E501


        :return: The tagged_recruiters of this CreateJobNoteRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tagged_recruiters

    @tagged_recruiters.setter
    def tagged_recruiters(self, tagged_recruiters):
        """Sets the tagged_recruiters of this CreateJobNoteRequest.


        :param tagged_recruiters: The tagged_recruiters of this CreateJobNoteRequest.  # noqa: E501
        :type: list[str]
        """
        if tagged_recruiters is None:
            raise ValueError("Invalid value for `tagged_recruiters`, must not be `None`")  # noqa: E501

        self._tagged_recruiters = tagged_recruiters

    @property
    def entity_type(self):
        """Gets the entity_type of this CreateJobNoteRequest.  # noqa: E501


        :return: The entity_type of this CreateJobNoteRequest.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this CreateJobNoteRequest.


        :param entity_type: The entity_type of this CreateJobNoteRequest.  # noqa: E501
        :type: str
        """
        if entity_type is None:
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501

        self._entity_type = entity_type

    @property
    def note_text(self):
        """Gets the note_text of this CreateJobNoteRequest.  # noqa: E501


        :return: The note_text of this CreateJobNoteRequest.  # noqa: E501
        :rtype: str
        """
        return self._note_text

    @note_text.setter
    def note_text(self, note_text):
        """Sets the note_text of this CreateJobNoteRequest.


        :param note_text: The note_text of this CreateJobNoteRequest.  # noqa: E501
        :type: str
        """
        if note_text is None:
            raise ValueError("Invalid value for `note_text`, must not be `None`")  # noqa: E501

        self._note_text = note_text

    @property
    def as_private(self):
        """Gets the as_private of this CreateJobNoteRequest.  # noqa: E501


        :return: The as_private of this CreateJobNoteRequest.  # noqa: E501
        :rtype: bool
        """
        return self._as_private

    @as_private.setter
    def as_private(self, as_private):
        """Sets the as_private of this CreateJobNoteRequest.


        :param as_private: The as_private of this CreateJobNoteRequest.  # noqa: E501
        :type: bool
        """
        if as_private is None:
            raise ValueError("Invalid value for `as_private`, must not be `None`")  # noqa: E501

        self._as_private = as_private

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateJobNoteRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateJobNoteRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    evaluation-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CandidateEvaluationsDataCandidateEvaluations(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'job_title': 'str',
        'type': 'str',
        'information': 'list[CandidateEvaluationsDataInformation]',
        'updated_date': 'str'
    }

    attribute_map = {
        'job_id': 'jobId',
        'job_title': 'jobTitle',
        'type': 'type',
        'information': 'information',
        'updated_date': 'updatedDate'
    }

    def __init__(self, job_id=None, job_title=None, type=None, information=None, updated_date=None):  # noqa: E501
        """CandidateEvaluationsDataCandidateEvaluations - a model defined in Swagger"""  # noqa: E501
        self._job_id = None
        self._job_title = None
        self._type = None
        self._information = None
        self._updated_date = None
        self.discriminator = None
        if job_id is not None:
            self.job_id = job_id
        if job_title is not None:
            self.job_title = job_title
        if type is not None:
            self.type = type
        if information is not None:
            self.information = information
        if updated_date is not None:
            self.updated_date = updated_date

    @property
    def job_id(self):
        """Gets the job_id of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501

        Job's reference id.  # noqa: E501

        :return: The job_id of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this CandidateEvaluationsDataCandidateEvaluations.

        Job's reference id.  # noqa: E501

        :param job_id: The job_id of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def job_title(self):
        """Gets the job_title of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501

        Job's title.  # noqa: E501

        :return: The job_title of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this CandidateEvaluationsDataCandidateEvaluations.

        Job's title.  # noqa: E501

        :param job_title: The job_title of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def type(self):
        """Gets the type of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501

        Type of evaluation provided, whether it be HRM or CRM.  # noqa: E501

        :return: The type of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CandidateEvaluationsDataCandidateEvaluations.

        Type of evaluation provided, whether it be HRM or CRM.  # noqa: E501

        :param type: The type of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def information(self):
        """Gets the information of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501

        List of information.  # noqa: E501

        :return: The information of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :rtype: list[CandidateEvaluationsDataInformation]
        """
        return self._information

    @information.setter
    def information(self, information):
        """Sets the information of this CandidateEvaluationsDataCandidateEvaluations.

        List of information.  # noqa: E501

        :param information: The information of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :type: list[CandidateEvaluationsDataInformation]
        """

        self._information = information

    @property
    def updated_date(self):
        """Gets the updated_date of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501

        Latest updated date.  # noqa: E501

        :return: The updated_date of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this CandidateEvaluationsDataCandidateEvaluations.

        Latest updated date.  # noqa: E501

        :param updated_date: The updated_date of this CandidateEvaluationsDataCandidateEvaluations.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CandidateEvaluationsDataCandidateEvaluations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CandidateEvaluationsDataCandidateEvaluations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidateJobNotesData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiters_user_id': 'str',
        'company_name': 'str',
        'new_note_display_text': 'str',
        'updated_date': 'str',
        'user_id': 'str',
        'job_id': 'str',
        'note_type': 'str',
        'created_date': 'str',
        'recruiter_name': 'str',
        'new_note_text': 'str',
        'id': 'str',
        'parent': 'str',
        'tagged_recruiters': 'list[str]',
        'as_private': 'bool'
    }

    attribute_map = {
        'recruiters_user_id': 'recruitersUserId',
        'company_name': 'companyName',
        'new_note_display_text': 'newNoteDisplayText',
        'updated_date': 'updatedDate',
        'user_id': 'userId',
        'job_id': 'jobId',
        'note_type': 'noteType',
        'created_date': 'createdDate',
        'recruiter_name': 'recruiterName',
        'new_note_text': 'newNoteText',
        'id': '_id',
        'parent': 'parent',
        'tagged_recruiters': 'taggedRecruiters',
        'as_private': 'asPrivate'
    }

    def __init__(self, recruiters_user_id=None, company_name=None, new_note_display_text=None, updated_date=None, user_id=None, job_id=None, note_type=None, created_date=None, recruiter_name=None, new_note_text=None, id=None, parent=None, tagged_recruiters=None, as_private=False):  # noqa: E501
        """GetCandidateJobNotesData - a model defined in Swagger"""  # noqa: E501
        self._recruiters_user_id = None
        self._company_name = None
        self._new_note_display_text = None
        self._updated_date = None
        self._user_id = None
        self._job_id = None
        self._note_type = None
        self._created_date = None
        self._recruiter_name = None
        self._new_note_text = None
        self._id = None
        self._parent = None
        self._tagged_recruiters = None
        self._as_private = None
        self.discriminator = None
        if recruiters_user_id is not None:
            self.recruiters_user_id = recruiters_user_id
        if company_name is not None:
            self.company_name = company_name
        if new_note_display_text is not None:
            self.new_note_display_text = new_note_display_text
        if updated_date is not None:
            self.updated_date = updated_date
        if user_id is not None:
            self.user_id = user_id
        if job_id is not None:
            self.job_id = job_id
        if note_type is not None:
            self.note_type = note_type
        if created_date is not None:
            self.created_date = created_date
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name
        if new_note_text is not None:
            self.new_note_text = new_note_text
        if id is not None:
            self.id = id
        if parent is not None:
            self.parent = parent
        if tagged_recruiters is not None:
            self.tagged_recruiters = tagged_recruiters
        if as_private is not None:
            self.as_private = as_private

    @property
    def recruiters_user_id(self):
        """Gets the recruiters_user_id of this GetCandidateJobNotesData.  # noqa: E501

        The user id of the recruiter.  # noqa: E501

        :return: The recruiters_user_id of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiters_user_id

    @recruiters_user_id.setter
    def recruiters_user_id(self, recruiters_user_id):
        """Sets the recruiters_user_id of this GetCandidateJobNotesData.

        The user id of the recruiter.  # noqa: E501

        :param recruiters_user_id: The recruiters_user_id of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._recruiters_user_id = recruiters_user_id

    @property
    def company_name(self):
        """Gets the company_name of this GetCandidateJobNotesData.  # noqa: E501

        The Name of the Company.  # noqa: E501

        :return: The company_name of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this GetCandidateJobNotesData.

        The Name of the Company.  # noqa: E501

        :param company_name: The company_name of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def new_note_display_text(self):
        """Gets the new_note_display_text of this GetCandidateJobNotesData.  # noqa: E501

        The text on the note.  # noqa: E501

        :return: The new_note_display_text of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._new_note_display_text

    @new_note_display_text.setter
    def new_note_display_text(self, new_note_display_text):
        """Sets the new_note_display_text of this GetCandidateJobNotesData.

        The text on the note.  # noqa: E501

        :param new_note_display_text: The new_note_display_text of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._new_note_display_text = new_note_display_text

    @property
    def updated_date(self):
        """Gets the updated_date of this GetCandidateJobNotesData.  # noqa: E501

        The date on which the note has been updated.  # noqa: E501

        :return: The updated_date of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this GetCandidateJobNotesData.

        The date on which the note has been updated.  # noqa: E501

        :param updated_date: The updated_date of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def user_id(self):
        """Gets the user_id of this GetCandidateJobNotesData.  # noqa: E501

        The Id of the candidate.  # noqa: E501

        :return: The user_id of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this GetCandidateJobNotesData.

        The Id of the candidate.  # noqa: E501

        :param user_id: The user_id of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def job_id(self):
        """Gets the job_id of this GetCandidateJobNotesData.  # noqa: E501

        The Id of the Job.  # noqa: E501

        :return: The job_id of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this GetCandidateJobNotesData.

        The Id of the Job.  # noqa: E501

        :param job_id: The job_id of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def note_type(self):
        """Gets the note_type of this GetCandidateJobNotesData.  # noqa: E501

        The Type of the current Note.  # noqa: E501

        :return: The note_type of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._note_type

    @note_type.setter
    def note_type(self, note_type):
        """Sets the note_type of this GetCandidateJobNotesData.

        The Type of the current Note.  # noqa: E501

        :param note_type: The note_type of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._note_type = note_type

    @property
    def created_date(self):
        """Gets the created_date of this GetCandidateJobNotesData.  # noqa: E501

        The Date on which the note has been created.  # noqa: E501

        :return: The created_date of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetCandidateJobNotesData.

        The Date on which the note has been created.  # noqa: E501

        :param created_date: The created_date of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this GetCandidateJobNotesData.  # noqa: E501

        The Name of the recruiter who created the note.  # noqa: E501

        :return: The recruiter_name of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this GetCandidateJobNotesData.

        The Name of the recruiter who created the note.  # noqa: E501

        :param recruiter_name: The recruiter_name of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    @property
    def new_note_text(self):
        """Gets the new_note_text of this GetCandidateJobNotesData.  # noqa: E501

        The Text on the note.  # noqa: E501

        :return: The new_note_text of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._new_note_text

    @new_note_text.setter
    def new_note_text(self, new_note_text):
        """Sets the new_note_text of this GetCandidateJobNotesData.

        The Text on the note.  # noqa: E501

        :param new_note_text: The new_note_text of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._new_note_text = new_note_text

    @property
    def id(self):
        """Gets the id of this GetCandidateJobNotesData.  # noqa: E501

        The unique identifier for the Note.  # noqa: E501

        :return: The id of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GetCandidateJobNotesData.

        The unique identifier for the Note.  # noqa: E501

        :param id: The id of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def parent(self):
        """Gets the parent of this GetCandidateJobNotesData.  # noqa: E501

        The unique identifier for candidate.  # noqa: E501

        :return: The parent of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this GetCandidateJobNotesData.

        The unique identifier for candidate.  # noqa: E501

        :param parent: The parent of this GetCandidateJobNotesData.  # noqa: E501
        :type: str
        """

        self._parent = parent

    @property
    def tagged_recruiters(self):
        """Gets the tagged_recruiters of this GetCandidateJobNotesData.  # noqa: E501

        The id of the user who are tagged in the note.  # noqa: E501

        :return: The tagged_recruiters of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: list[str]
        """
        return self._tagged_recruiters

    @tagged_recruiters.setter
    def tagged_recruiters(self, tagged_recruiters):
        """Sets the tagged_recruiters of this GetCandidateJobNotesData.

        The id of the user who are tagged in the note.  # noqa: E501

        :param tagged_recruiters: The tagged_recruiters of this GetCandidateJobNotesData.  # noqa: E501
        :type: list[str]
        """

        self._tagged_recruiters = tagged_recruiters

    @property
    def as_private(self):
        """Gets the as_private of this GetCandidateJobNotesData.  # noqa: E501

        The Boolean value to represent the visibility of note.  # noqa: E501

        :return: The as_private of this GetCandidateJobNotesData.  # noqa: E501
        :rtype: bool
        """
        return self._as_private

    @as_private.setter
    def as_private(self, as_private):
        """Sets the as_private of this GetCandidateJobNotesData.

        The Boolean value to represent the visibility of note.  # noqa: E501

        :param as_private: The as_private of this GetCandidateJobNotesData.  # noqa: E501
        :type: bool
        """

        self._as_private = as_private

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidateJobNotesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidateJobNotesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class CandidatesApi(object):
    base_path = "/projects-api"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def add_candidate_to_project(self, body, x_ph_userid, project_id, **kwargs):  # noqa: E501
        """Add Candidates to Project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_candidate_to_project(body, x_ph_userid, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssignCandidatesToProject body: Create Project (required)
        :param str x_ph_userid: (required)
        :param str project_id: (required)
        :return: AssignCandidateToProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_candidate_to_project_with_http_info(body, x_ph_userid, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_candidate_to_project_with_http_info(body, x_ph_userid, project_id, **kwargs)  # noqa: E501
            return data

    def add_candidate_to_project_with_http_info(self, body, x_ph_userid, project_id, **kwargs):  # noqa: E501
        """Add Candidates to Project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_candidate_to_project_with_http_info(body, x_ph_userid, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssignCandidatesToProject body: Create Project (required)
        :param str x_ph_userid: (required)
        :param str project_id: (required)
        :return: AssignCandidateToProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_candidate_to_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `add_candidate_to_project`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `add_candidate_to_project`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `add_candidate_to_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/candidates', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssignCandidateToProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_associated_candidate_ids(self, x_ph_userid, project_id, **kwargs):  # noqa: E501
        """Get CandidateIds for Project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_associated_candidate_ids(x_ph_userid, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param str project_id: (required)
        :param int _from: The number of candidates to skip before starting to collect the result.
        :param int size: The number of candidates to be included in the result.
        :return: GetProjectAssociationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_associated_candidate_ids_with_http_info(x_ph_userid, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_associated_candidate_ids_with_http_info(x_ph_userid, project_id, **kwargs)  # noqa: E501
            return data

    def get_associated_candidate_ids_with_http_info(self, x_ph_userid, project_id, **kwargs):  # noqa: E501
        """Get CandidateIds for Project.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_associated_candidate_ids_with_http_info(x_ph_userid, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param str project_id: (required)
        :param int _from: The number of candidates to skip before starting to collect the result.
        :param int size: The number of candidates to be included in the result.
        :return: GetProjectAssociationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_userid', 'project_id', '_from', 'size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_associated_candidate_ids" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_associated_candidate_ids`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `get_associated_candidate_ids`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/candidates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetProjectAssociationsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_project_activities(self, candidate_id, x_ph_userid, **kwargs):  # noqa: E501
        """Get project Activities  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_activities(candidate_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: candidateId (required)
        :param str x_ph_userid: (required)
        :param int _from: The number of activities to skip before starting to collect the result
        :param int size: size of the result
        :return: GetProjectActivitiesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_project_activities_with_http_info(candidate_id, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_project_activities_with_http_info(candidate_id, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def get_project_activities_with_http_info(self, candidate_id, x_ph_userid, **kwargs):  # noqa: E501
        """Get project Activities  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_activities_with_http_info(candidate_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: candidateId (required)
        :param str x_ph_userid: (required)
        :param int _from: The number of activities to skip before starting to collect the result
        :param int size: size of the result
        :return: GetProjectActivitiesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'x_ph_userid', '_from', 'size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_project_activities" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_project_activities`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_project_activities`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/project-activities', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetProjectActivitiesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_candidate_from_project(self, project_id, candidate_id, x_ph_userid, **kwargs):  # noqa: E501
        """Delete candidate from project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_candidate_from_project(project_id, candidate_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: The projectId from which the candidate needs to be removed (required)
        :param str candidate_id: The userId of the candidate whom needs to be removed (required)
        :param str x_ph_userid: (required)
        :return: DeleteCandidateFromProject
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_candidate_from_project_with_http_info(project_id, candidate_id, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_candidate_from_project_with_http_info(project_id, candidate_id, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def remove_candidate_from_project_with_http_info(self, project_id, candidate_id, x_ph_userid, **kwargs):  # noqa: E501
        """Delete candidate from project  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_candidate_from_project_with_http_info(project_id, candidate_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: The projectId from which the candidate needs to be removed (required)
        :param str candidate_id: The userId of the candidate whom needs to be removed (required)
        :param str x_ph_userid: (required)
        :return: DeleteCandidateFromProject
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'candidate_id', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_candidate_from_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `remove_candidate_from_project`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `remove_candidate_from_project`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `remove_candidate_from_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/candidates/{candidateId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteCandidateFromProject',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectsResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_name': 'str',
        'project_description': 'str',
        'project_id': 'str',
        'created_date': 'str',
        'updated_date': 'str',
        'end_date': 'str',
        'status': 'str',
        'is_confidential': 'str',
        'created_recruiter_info': 'GetProjectsResponseCreatedRecruiterInfo',
        'updated_recruiter_info': 'GetProjectsResponseUpdatedRecruiterInfo',
        'workflow_id': 'str',
        'workflow_name': 'str',
        'brand': 'str',
        'source': 'str',
        'hiring_team_list': 'list[GetProjectsResponseHiringTeamList]',
        'category_list': 'list[object]',
        'project_attachment_list': 'list[object]',
        'matching_criteria': 'GetProjectsResponseMatchingCriteria',
        'category_names': 'list[object]',
        'confidential': 'str',
        'candidate_infos': 'list[GetProjectsResponseCandidateInfos]'
    }

    attribute_map = {
        'project_name': 'projectName',
        'project_description': 'projectDescription',
        'project_id': 'projectId',
        'created_date': 'createdDate',
        'updated_date': 'updatedDate',
        'end_date': 'endDate',
        'status': 'status',
        'is_confidential': 'isConfidential',
        'created_recruiter_info': 'createdRecruiterInfo',
        'updated_recruiter_info': 'updatedRecruiterInfo',
        'workflow_id': 'workflowId',
        'workflow_name': 'workflowName',
        'brand': 'brand',
        'source': 'source',
        'hiring_team_list': 'hiringTeamList',
        'category_list': 'categoryList',
        'project_attachment_list': 'projectAttachmentList',
        'matching_criteria': 'matchingCriteria',
        'category_names': 'categoryNames',
        'confidential': 'confidential',
        'candidate_infos': 'candidateInfos'
    }

    def __init__(self, project_name=None, project_description=None, project_id=None, created_date=None, updated_date=None, end_date=None, status=None, is_confidential=None, created_recruiter_info=None, updated_recruiter_info=None, workflow_id=None, workflow_name=None, brand=None, source=None, hiring_team_list=None, category_list=None, project_attachment_list=None, matching_criteria=None, category_names=None, confidential=None, candidate_infos=None):  # noqa: E501
        """GetProjectsResponseData - a model defined in Swagger"""  # noqa: E501
        self._project_name = None
        self._project_description = None
        self._project_id = None
        self._created_date = None
        self._updated_date = None
        self._end_date = None
        self._status = None
        self._is_confidential = None
        self._created_recruiter_info = None
        self._updated_recruiter_info = None
        self._workflow_id = None
        self._workflow_name = None
        self._brand = None
        self._source = None
        self._hiring_team_list = None
        self._category_list = None
        self._project_attachment_list = None
        self._matching_criteria = None
        self._category_names = None
        self._confidential = None
        self._candidate_infos = None
        self.discriminator = None
        self.project_name = project_name
        self.project_description = project_description
        self.project_id = project_id
        self.created_date = created_date
        self.updated_date = updated_date
        self.end_date = end_date
        self.status = status
        self.is_confidential = is_confidential
        self.created_recruiter_info = created_recruiter_info
        self.updated_recruiter_info = updated_recruiter_info
        self.workflow_id = workflow_id
        self.workflow_name = workflow_name
        self.brand = brand
        self.source = source
        self.hiring_team_list = hiring_team_list
        self.category_list = category_list
        self.project_attachment_list = project_attachment_list
        self.matching_criteria = matching_criteria
        self.category_names = category_names
        self.confidential = confidential
        self.candidate_infos = candidate_infos

    @property
    def project_name(self):
        """Gets the project_name of this GetProjectsResponseData.  # noqa: E501

        The name of the project.  # noqa: E501

        :return: The project_name of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this GetProjectsResponseData.

        The name of the project.  # noqa: E501

        :param project_name: The project_name of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if project_name is None:
            raise ValueError("Invalid value for `project_name`, must not be `None`")  # noqa: E501

        self._project_name = project_name

    @property
    def project_description(self):
        """Gets the project_description of this GetProjectsResponseData.  # noqa: E501

        The description of the project.  # noqa: E501

        :return: The project_description of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._project_description

    @project_description.setter
    def project_description(self, project_description):
        """Sets the project_description of this GetProjectsResponseData.

        The description of the project.  # noqa: E501

        :param project_description: The project_description of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if project_description is None:
            raise ValueError("Invalid value for `project_description`, must not be `None`")  # noqa: E501

        self._project_description = project_description

    @property
    def project_id(self):
        """Gets the project_id of this GetProjectsResponseData.  # noqa: E501

        The unique identifier for the project.  # noqa: E501

        :return: The project_id of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this GetProjectsResponseData.

        The unique identifier for the project.  # noqa: E501

        :param project_id: The project_id of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def created_date(self):
        """Gets the created_date of this GetProjectsResponseData.  # noqa: E501

        The date when the project was created.  # noqa: E501

        :return: The created_date of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetProjectsResponseData.

        The date when the project was created.  # noqa: E501

        :param created_date: The created_date of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def updated_date(self):
        """Gets the updated_date of this GetProjectsResponseData.  # noqa: E501

        The date when the project was last updated.  # noqa: E501

        :return: The updated_date of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this GetProjectsResponseData.

        The date when the project was last updated.  # noqa: E501

        :param updated_date: The updated_date of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if updated_date is None:
            raise ValueError("Invalid value for `updated_date`, must not be `None`")  # noqa: E501

        self._updated_date = updated_date

    @property
    def end_date(self):
        """Gets the end_date of this GetProjectsResponseData.  # noqa: E501

        The end date of the project.  # noqa: E501

        :return: The end_date of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this GetProjectsResponseData.

        The end date of the project.  # noqa: E501

        :param end_date: The end_date of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def status(self):
        """Gets the status of this GetProjectsResponseData.  # noqa: E501

        The status of the project.  # noqa: E501

        :return: The status of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetProjectsResponseData.

        The status of the project.  # noqa: E501

        :param status: The status of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def is_confidential(self):
        """Gets the is_confidential of this GetProjectsResponseData.  # noqa: E501

        Indicates whether the project is confidential.  # noqa: E501

        :return: The is_confidential of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._is_confidential

    @is_confidential.setter
    def is_confidential(self, is_confidential):
        """Sets the is_confidential of this GetProjectsResponseData.

        Indicates whether the project is confidential.  # noqa: E501

        :param is_confidential: The is_confidential of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if is_confidential is None:
            raise ValueError("Invalid value for `is_confidential`, must not be `None`")  # noqa: E501

        self._is_confidential = is_confidential

    @property
    def created_recruiter_info(self):
        """Gets the created_recruiter_info of this GetProjectsResponseData.  # noqa: E501


        :return: The created_recruiter_info of this GetProjectsResponseData.  # noqa: E501
        :rtype: GetProjectsResponseCreatedRecruiterInfo
        """
        return self._created_recruiter_info

    @created_recruiter_info.setter
    def created_recruiter_info(self, created_recruiter_info):
        """Sets the created_recruiter_info of this GetProjectsResponseData.


        :param created_recruiter_info: The created_recruiter_info of this GetProjectsResponseData.  # noqa: E501
        :type: GetProjectsResponseCreatedRecruiterInfo
        """
        if created_recruiter_info is None:
            raise ValueError("Invalid value for `created_recruiter_info`, must not be `None`")  # noqa: E501

        self._created_recruiter_info = created_recruiter_info

    @property
    def updated_recruiter_info(self):
        """Gets the updated_recruiter_info of this GetProjectsResponseData.  # noqa: E501


        :return: The updated_recruiter_info of this GetProjectsResponseData.  # noqa: E501
        :rtype: GetProjectsResponseUpdatedRecruiterInfo
        """
        return self._updated_recruiter_info

    @updated_recruiter_info.setter
    def updated_recruiter_info(self, updated_recruiter_info):
        """Sets the updated_recruiter_info of this GetProjectsResponseData.


        :param updated_recruiter_info: The updated_recruiter_info of this GetProjectsResponseData.  # noqa: E501
        :type: GetProjectsResponseUpdatedRecruiterInfo
        """
        if updated_recruiter_info is None:
            raise ValueError("Invalid value for `updated_recruiter_info`, must not be `None`")  # noqa: E501

        self._updated_recruiter_info = updated_recruiter_info

    @property
    def workflow_id(self):
        """Gets the workflow_id of this GetProjectsResponseData.  # noqa: E501

        The unique identifier for the workflow associated with the project.  # noqa: E501

        :return: The workflow_id of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this GetProjectsResponseData.

        The unique identifier for the workflow associated with the project.  # noqa: E501

        :param workflow_id: The workflow_id of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if workflow_id is None:
            raise ValueError("Invalid value for `workflow_id`, must not be `None`")  # noqa: E501

        self._workflow_id = workflow_id

    @property
    def workflow_name(self):
        """Gets the workflow_name of this GetProjectsResponseData.  # noqa: E501

        The name of the workflow associated with the project.  # noqa: E501

        :return: The workflow_name of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._workflow_name

    @workflow_name.setter
    def workflow_name(self, workflow_name):
        """Sets the workflow_name of this GetProjectsResponseData.

        The name of the workflow associated with the project.  # noqa: E501

        :param workflow_name: The workflow_name of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if workflow_name is None:
            raise ValueError("Invalid value for `workflow_name`, must not be `None`")  # noqa: E501

        self._workflow_name = workflow_name

    @property
    def brand(self):
        """Gets the brand of this GetProjectsResponseData.  # noqa: E501

        The brand associated with the project.  # noqa: E501

        :return: The brand of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this GetProjectsResponseData.

        The brand associated with the project.  # noqa: E501

        :param brand: The brand of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if brand is None:
            raise ValueError("Invalid value for `brand`, must not be `None`")  # noqa: E501

        self._brand = brand

    @property
    def source(self):
        """Gets the source of this GetProjectsResponseData.  # noqa: E501

        The source of the project.  # noqa: E501

        :return: The source of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this GetProjectsResponseData.

        The source of the project.  # noqa: E501

        :param source: The source of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def hiring_team_list(self):
        """Gets the hiring_team_list of this GetProjectsResponseData.  # noqa: E501

        An array containing details of the hiring team for the project.  # noqa: E501

        :return: The hiring_team_list of this GetProjectsResponseData.  # noqa: E501
        :rtype: list[GetProjectsResponseHiringTeamList]
        """
        return self._hiring_team_list

    @hiring_team_list.setter
    def hiring_team_list(self, hiring_team_list):
        """Sets the hiring_team_list of this GetProjectsResponseData.

        An array containing details of the hiring team for the project.  # noqa: E501

        :param hiring_team_list: The hiring_team_list of this GetProjectsResponseData.  # noqa: E501
        :type: list[GetProjectsResponseHiringTeamList]
        """
        if hiring_team_list is None:
            raise ValueError("Invalid value for `hiring_team_list`, must not be `None`")  # noqa: E501

        self._hiring_team_list = hiring_team_list

    @property
    def category_list(self):
        """Gets the category_list of this GetProjectsResponseData.  # noqa: E501

        An array containing details of categories associated with the project.  # noqa: E501

        :return: The category_list of this GetProjectsResponseData.  # noqa: E501
        :rtype: list[object]
        """
        return self._category_list

    @category_list.setter
    def category_list(self, category_list):
        """Sets the category_list of this GetProjectsResponseData.

        An array containing details of categories associated with the project.  # noqa: E501

        :param category_list: The category_list of this GetProjectsResponseData.  # noqa: E501
        :type: list[object]
        """
        if category_list is None:
            raise ValueError("Invalid value for `category_list`, must not be `None`")  # noqa: E501

        self._category_list = category_list

    @property
    def project_attachment_list(self):
        """Gets the project_attachment_list of this GetProjectsResponseData.  # noqa: E501

        An array containing details of attachments associated with the project.  # noqa: E501

        :return: The project_attachment_list of this GetProjectsResponseData.  # noqa: E501
        :rtype: list[object]
        """
        return self._project_attachment_list

    @project_attachment_list.setter
    def project_attachment_list(self, project_attachment_list):
        """Sets the project_attachment_list of this GetProjectsResponseData.

        An array containing details of attachments associated with the project.  # noqa: E501

        :param project_attachment_list: The project_attachment_list of this GetProjectsResponseData.  # noqa: E501
        :type: list[object]
        """
        if project_attachment_list is None:
            raise ValueError("Invalid value for `project_attachment_list`, must not be `None`")  # noqa: E501

        self._project_attachment_list = project_attachment_list

    @property
    def matching_criteria(self):
        """Gets the matching_criteria of this GetProjectsResponseData.  # noqa: E501


        :return: The matching_criteria of this GetProjectsResponseData.  # noqa: E501
        :rtype: GetProjectsResponseMatchingCriteria
        """
        return self._matching_criteria

    @matching_criteria.setter
    def matching_criteria(self, matching_criteria):
        """Sets the matching_criteria of this GetProjectsResponseData.


        :param matching_criteria: The matching_criteria of this GetProjectsResponseData.  # noqa: E501
        :type: GetProjectsResponseMatchingCriteria
        """
        if matching_criteria is None:
            raise ValueError("Invalid value for `matching_criteria`, must not be `None`")  # noqa: E501

        self._matching_criteria = matching_criteria

    @property
    def category_names(self):
        """Gets the category_names of this GetProjectsResponseData.  # noqa: E501

        An array containing names of categories associated with the project.  # noqa: E501

        :return: The category_names of this GetProjectsResponseData.  # noqa: E501
        :rtype: list[object]
        """
        return self._category_names

    @category_names.setter
    def category_names(self, category_names):
        """Sets the category_names of this GetProjectsResponseData.

        An array containing names of categories associated with the project.  # noqa: E501

        :param category_names: The category_names of this GetProjectsResponseData.  # noqa: E501
        :type: list[object]
        """
        if category_names is None:
            raise ValueError("Invalid value for `category_names`, must not be `None`")  # noqa: E501

        self._category_names = category_names

    @property
    def confidential(self):
        """Gets the confidential of this GetProjectsResponseData.  # noqa: E501

        Indicates whether the project is confidential.  # noqa: E501

        :return: The confidential of this GetProjectsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._confidential

    @confidential.setter
    def confidential(self, confidential):
        """Sets the confidential of this GetProjectsResponseData.

        Indicates whether the project is confidential.  # noqa: E501

        :param confidential: The confidential of this GetProjectsResponseData.  # noqa: E501
        :type: str
        """
        if confidential is None:
            raise ValueError("Invalid value for `confidential`, must not be `None`")  # noqa: E501

        self._confidential = confidential

    @property
    def candidate_infos(self):
        """Gets the candidate_infos of this GetProjectsResponseData.  # noqa: E501

        An array containing details of candidates associated with the project.  # noqa: E501

        :return: The candidate_infos of this GetProjectsResponseData.  # noqa: E501
        :rtype: list[GetProjectsResponseCandidateInfos]
        """
        return self._candidate_infos

    @candidate_infos.setter
    def candidate_infos(self, candidate_infos):
        """Sets the candidate_infos of this GetProjectsResponseData.

        An array containing details of candidates associated with the project.  # noqa: E501

        :param candidate_infos: The candidate_infos of this GetProjectsResponseData.  # noqa: E501
        :type: list[GetProjectsResponseCandidateInfos]
        """
        if candidate_infos is None:
            raise ValueError("Invalid value for `candidate_infos`, must not be `None`")  # noqa: E501

        self._candidate_infos = candidate_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectsResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectsResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.videoplatform.review_api import ReviewApi
from phenom.api.videoplatform.evaluations_api import EvaluationsApi
from phenom.api.videoplatform.questions_api import QuestionsApi
from phenom.api.videoplatform.candidate_invite_api import CandidateInviteApi
from phenom.api.videoplatform.job_questionnaire_config_api import JobQuestionnaireConfigApi
from phenom.api.videoplatform.questionnaire_templates_api import QuestionnaireTemplatesApi

class InterviewScreening(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def review_api(self):
        return ReviewApi(self.__token, self.__gateway_url, self.__apikey)

    def evaluations_api(self):
        return EvaluationsApi(self.__token, self.__gateway_url, self.__apikey)

    def questions_api(self):
        return QuestionsApi(self.__token, self.__gateway_url, self.__apikey)

    def candidate_invite_api(self):
        return CandidateInviteApi(self.__token, self.__gateway_url, self.__apikey)

    def job_questionnaire_config_api(self):
        return JobQuestionnaireConfigApi(self.__token, self.__gateway_url, self.__apikey)

    def questionnaire_templates_api(self):
        return QuestionnaireTemplatesApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmailCampaignActivityData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email_activity_id': 'str',
        'email': 'str',
        'event': 'str',
        'ip': 'str',
        'created_date': 'int',
        'useragent': 'str'
    }

    attribute_map = {
        'email_activity_id': 'emailActivityId',
        'email': 'email',
        'event': 'event',
        'ip': 'ip',
        'created_date': 'createdDate',
        'useragent': 'useragent'
    }

    def __init__(self, email_activity_id=None, email=None, event=None, ip=None, created_date=None, useragent=None):  # noqa: E501
        """EmailCampaignActivityData - a model defined in Swagger"""  # noqa: E501
        self._email_activity_id = None
        self._email = None
        self._event = None
        self._ip = None
        self._created_date = None
        self._useragent = None
        self.discriminator = None
        self.email_activity_id = email_activity_id
        self.email = email
        self.event = event
        self.ip = ip
        self.created_date = created_date
        self.useragent = useragent

    @property
    def email_activity_id(self):
        """Gets the email_activity_id of this EmailCampaignActivityData.  # noqa: E501

        Unique identifier for the email activity.  # noqa: E501

        :return: The email_activity_id of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._email_activity_id

    @email_activity_id.setter
    def email_activity_id(self, email_activity_id):
        """Sets the email_activity_id of this EmailCampaignActivityData.

        Unique identifier for the email activity.  # noqa: E501

        :param email_activity_id: The email_activity_id of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if email_activity_id is None:
            raise ValueError("Invalid value for `email_activity_id`, must not be `None`")  # noqa: E501

        self._email_activity_id = email_activity_id

    @property
    def email(self):
        """Gets the email of this EmailCampaignActivityData.  # noqa: E501

        Email address associated with the email campaign activity.  # noqa: E501

        :return: The email of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this EmailCampaignActivityData.

        Email address associated with the email campaign activity.  # noqa: E501

        :param email: The email of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def event(self):
        """Gets the event of this EmailCampaignActivityData.  # noqa: E501

        Event associated with email campaign activity.  # noqa: E501

        :return: The event of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this EmailCampaignActivityData.

        Event associated with email campaign activity.  # noqa: E501

        :param event: The event of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if event is None:
            raise ValueError("Invalid value for `event`, must not be `None`")  # noqa: E501

        self._event = event

    @property
    def ip(self):
        """Gets the ip of this EmailCampaignActivityData.  # noqa: E501

        IP address associated with the email activity.  # noqa: E501

        :return: The ip of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this EmailCampaignActivityData.

        IP address associated with the email activity.  # noqa: E501

        :param ip: The ip of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if ip is None:
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def created_date(self):
        """Gets the created_date of this EmailCampaignActivityData.  # noqa: E501

        Timestamp indicating when the email activity was created.  # noqa: E501

        :return: The created_date of this EmailCampaignActivityData.  # noqa: E501
        :rtype: int
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this EmailCampaignActivityData.

        Timestamp indicating when the email activity was created.  # noqa: E501

        :param created_date: The created_date of this EmailCampaignActivityData.  # noqa: E501
        :type: int
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def useragent(self):
        """Gets the useragent of this EmailCampaignActivityData.  # noqa: E501

        User agent information associated with the email activity.  # noqa: E501

        :return: The useragent of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._useragent

    @useragent.setter
    def useragent(self, useragent):
        """Sets the useragent of this EmailCampaignActivityData.

        User agent information associated with the email activity.  # noqa: E501

        :param useragent: The useragent of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if useragent is None:
            raise ValueError("Invalid value for `useragent`, must not be `None`")  # noqa: E501

        self._useragent = useragent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailCampaignActivityData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailCampaignActivityData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobActivitiesTrafficSourceList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'source_short_name': 'str',
        'source_fullname': 'str',
        'referral_type': 'str',
        'created_date': 'str',
        'raw_url': 'str'
    }

    attribute_map = {
        'source_short_name': 'sourceShortName',
        'source_fullname': 'sourceFullname',
        'referral_type': 'referralType',
        'created_date': 'createdDate',
        'raw_url': 'rawUrl'
    }

    def __init__(self, source_short_name=None, source_fullname=None, referral_type=None, created_date=None, raw_url=None):  # noqa: E501
        """JobActivitiesTrafficSourceList - a model defined in Swagger"""  # noqa: E501
        self._source_short_name = None
        self._source_fullname = None
        self._referral_type = None
        self._created_date = None
        self._raw_url = None
        self.discriminator = None
        if source_short_name is not None:
            self.source_short_name = source_short_name
        if source_fullname is not None:
            self.source_fullname = source_fullname
        if referral_type is not None:
            self.referral_type = referral_type
        if created_date is not None:
            self.created_date = created_date
        if raw_url is not None:
            self.raw_url = raw_url

    @property
    def source_short_name(self):
        """Gets the source_short_name of this JobActivitiesTrafficSourceList.  # noqa: E501

        Short name of the traffic source.  # noqa: E501

        :return: The source_short_name of this JobActivitiesTrafficSourceList.  # noqa: E501
        :rtype: str
        """
        return self._source_short_name

    @source_short_name.setter
    def source_short_name(self, source_short_name):
        """Sets the source_short_name of this JobActivitiesTrafficSourceList.

        Short name of the traffic source.  # noqa: E501

        :param source_short_name: The source_short_name of this JobActivitiesTrafficSourceList.  # noqa: E501
        :type: str
        """

        self._source_short_name = source_short_name

    @property
    def source_fullname(self):
        """Gets the source_fullname of this JobActivitiesTrafficSourceList.  # noqa: E501

        Full name of the traffic source.  # noqa: E501

        :return: The source_fullname of this JobActivitiesTrafficSourceList.  # noqa: E501
        :rtype: str
        """
        return self._source_fullname

    @source_fullname.setter
    def source_fullname(self, source_fullname):
        """Sets the source_fullname of this JobActivitiesTrafficSourceList.

        Full name of the traffic source.  # noqa: E501

        :param source_fullname: The source_fullname of this JobActivitiesTrafficSourceList.  # noqa: E501
        :type: str
        """

        self._source_fullname = source_fullname

    @property
    def referral_type(self):
        """Gets the referral_type of this JobActivitiesTrafficSourceList.  # noqa: E501

        Type of referral from the traffic source.  # noqa: E501

        :return: The referral_type of this JobActivitiesTrafficSourceList.  # noqa: E501
        :rtype: str
        """
        return self._referral_type

    @referral_type.setter
    def referral_type(self, referral_type):
        """Sets the referral_type of this JobActivitiesTrafficSourceList.

        Type of referral from the traffic source.  # noqa: E501

        :param referral_type: The referral_type of this JobActivitiesTrafficSourceList.  # noqa: E501
        :type: str
        """

        self._referral_type = referral_type

    @property
    def created_date(self):
        """Gets the created_date of this JobActivitiesTrafficSourceList.  # noqa: E501

        Date when the traffic source was created.  # noqa: E501

        :return: The created_date of this JobActivitiesTrafficSourceList.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this JobActivitiesTrafficSourceList.

        Date when the traffic source was created.  # noqa: E501

        :param created_date: The created_date of this JobActivitiesTrafficSourceList.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def raw_url(self):
        """Gets the raw_url of this JobActivitiesTrafficSourceList.  # noqa: E501

        Raw URL associated with the traffic source.  # noqa: E501

        :return: The raw_url of this JobActivitiesTrafficSourceList.  # noqa: E501
        :rtype: str
        """
        return self._raw_url

    @raw_url.setter
    def raw_url(self, raw_url):
        """Sets the raw_url of this JobActivitiesTrafficSourceList.

        Raw URL associated with the traffic source.  # noqa: E501

        :param raw_url: The raw_url of this JobActivitiesTrafficSourceList.  # noqa: E501
        :type: str
        """

        self._raw_url = raw_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobActivitiesTrafficSourceList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobActivitiesTrafficSourceList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ApplicantsDataCandidates(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'emails': 'list[str]',
        'last_name': 'str',
        'first_name': 'str',
        'date_created': 'str',
        'hiring_status': 'str',
        'updated_date': 'str',
        'user_id': 'str',
        'contacts': 'list[ApplicantsDataContacts]'
    }

    attribute_map = {
        'emails': 'emails',
        'last_name': 'lastName',
        'first_name': 'firstName',
        'date_created': 'dateCreated',
        'hiring_status': 'hiringStatus',
        'updated_date': 'updatedDate',
        'user_id': 'userId',
        'contacts': 'contacts'
    }

    def __init__(self, emails=None, last_name=None, first_name=None, date_created=None, hiring_status=None, updated_date=None, user_id=None, contacts=None):  # noqa: E501
        """ApplicantsDataCandidates - a model defined in Swagger"""  # noqa: E501
        self._emails = None
        self._last_name = None
        self._first_name = None
        self._date_created = None
        self._hiring_status = None
        self._updated_date = None
        self._user_id = None
        self._contacts = None
        self.discriminator = None
        if emails is not None:
            self.emails = emails
        if last_name is not None:
            self.last_name = last_name
        if first_name is not None:
            self.first_name = first_name
        if date_created is not None:
            self.date_created = date_created
        if hiring_status is not None:
            self.hiring_status = hiring_status
        if updated_date is not None:
            self.updated_date = updated_date
        if user_id is not None:
            self.user_id = user_id
        if contacts is not None:
            self.contacts = contacts

    @property
    def emails(self):
        """Gets the emails of this ApplicantsDataCandidates.  # noqa: E501

        Array of email addresses associated with the candidate.  # noqa: E501

        :return: The emails of this ApplicantsDataCandidates.  # noqa: E501
        :rtype: list[str]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this ApplicantsDataCandidates.

        Array of email addresses associated with the candidate.  # noqa: E501

        :param emails: The emails of this ApplicantsDataCandidates.  # noqa: E501
        :type: list[str]
        """

        self._emails = emails

    @property
    def last_name(self):
        """Gets the last_name of this ApplicantsDataCandidates.  # noqa: E501

        Last name of the candidate.  # noqa: E501

        :return: The last_name of this ApplicantsDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ApplicantsDataCandidates.

        Last name of the candidate.  # noqa: E501

        :param last_name: The last_name of this ApplicantsDataCandidates.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def first_name(self):
        """Gets the first_name of this ApplicantsDataCandidates.  # noqa: E501

        First name of the candidate.  # noqa: E501

        :return: The first_name of this ApplicantsDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ApplicantsDataCandidates.

        First name of the candidate.  # noqa: E501

        :param first_name: The first_name of this ApplicantsDataCandidates.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def date_created(self):
        """Gets the date_created of this ApplicantsDataCandidates.  # noqa: E501

        Date when the candidate record was created.  # noqa: E501

        :return: The date_created of this ApplicantsDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this ApplicantsDataCandidates.

        Date when the candidate record was created.  # noqa: E501

        :param date_created: The date_created of this ApplicantsDataCandidates.  # noqa: E501
        :type: str
        """

        self._date_created = date_created

    @property
    def hiring_status(self):
        """Gets the hiring_status of this ApplicantsDataCandidates.  # noqa: E501

        Current hiring status of the candidate.  # noqa: E501

        :return: The hiring_status of this ApplicantsDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._hiring_status

    @hiring_status.setter
    def hiring_status(self, hiring_status):
        """Sets the hiring_status of this ApplicantsDataCandidates.

        Current hiring status of the candidate.  # noqa: E501

        :param hiring_status: The hiring_status of this ApplicantsDataCandidates.  # noqa: E501
        :type: str
        """

        self._hiring_status = hiring_status

    @property
    def updated_date(self):
        """Gets the updated_date of this ApplicantsDataCandidates.  # noqa: E501

        Date when the candidate record was last updated.  # noqa: E501

        :return: The updated_date of this ApplicantsDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this ApplicantsDataCandidates.

        Date when the candidate record was last updated.  # noqa: E501

        :param updated_date: The updated_date of this ApplicantsDataCandidates.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def user_id(self):
        """Gets the user_id of this ApplicantsDataCandidates.  # noqa: E501

        Unique identifier for the candidate user.  # noqa: E501

        :return: The user_id of this ApplicantsDataCandidates.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ApplicantsDataCandidates.

        Unique identifier for the candidate user.  # noqa: E501

        :param user_id: The user_id of this ApplicantsDataCandidates.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def contacts(self):
        """Gets the contacts of this ApplicantsDataCandidates.  # noqa: E501

        Array of contact details associated with the candidate.  # noqa: E501

        :return: The contacts of this ApplicantsDataCandidates.  # noqa: E501
        :rtype: list[ApplicantsDataContacts]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this ApplicantsDataCandidates.

        Array of contact details associated with the candidate.  # noqa: E501

        :param contacts: The contacts of this ApplicantsDataCandidates.  # noqa: E501
        :type: list[ApplicantsDataContacts]
        """

        self._contacts = contacts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApplicantsDataCandidates, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicantsDataCandidates):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobActivitiesData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_category': 'str',
        'job_title': 'str',
        'site_type': 'str',
        'traffic_source_list': 'list[JobActivitiesTrafficSourceList]',
        'job_location': 'str',
        'updated_date': 'str',
        'field_id': 'str',
        'locale': 'str',
        'job_id': 'str',
        'action_type': 'str',
        'is_confidential': 'str',
        'created_date': 'str',
        'traffic_sources': 'list[JobActivitiesTrafficSourceList]'
    }

    attribute_map = {
        'job_category': 'jobCategory',
        'job_title': 'jobTitle',
        'site_type': 'siteType',
        'traffic_source_list': 'trafficSourceList',
        'job_location': 'jobLocation',
        'updated_date': 'updatedDate',
        'field_id': 'fieldID',
        'locale': 'locale',
        'job_id': 'jobId',
        'action_type': 'actionType',
        'is_confidential': 'isConfidential',
        'created_date': 'createdDate',
        'traffic_sources': 'trafficSources'
    }

    def __init__(self, job_category=None, job_title=None, site_type=None, traffic_source_list=None, job_location=None, updated_date=None, field_id=None, locale=None, job_id=None, action_type=None, is_confidential=None, created_date=None, traffic_sources=None):  # noqa: E501
        """JobActivitiesData - a model defined in Swagger"""  # noqa: E501
        self._job_category = None
        self._job_title = None
        self._site_type = None
        self._traffic_source_list = None
        self._job_location = None
        self._updated_date = None
        self._field_id = None
        self._locale = None
        self._job_id = None
        self._action_type = None
        self._is_confidential = None
        self._created_date = None
        self._traffic_sources = None
        self.discriminator = None
        if job_category is not None:
            self.job_category = job_category
        if job_title is not None:
            self.job_title = job_title
        if site_type is not None:
            self.site_type = site_type
        if traffic_source_list is not None:
            self.traffic_source_list = traffic_source_list
        if job_location is not None:
            self.job_location = job_location
        if updated_date is not None:
            self.updated_date = updated_date
        if field_id is not None:
            self.field_id = field_id
        if locale is not None:
            self.locale = locale
        if job_id is not None:
            self.job_id = job_id
        if action_type is not None:
            self.action_type = action_type
        if is_confidential is not None:
            self.is_confidential = is_confidential
        if created_date is not None:
            self.created_date = created_date
        if traffic_sources is not None:
            self.traffic_sources = traffic_sources

    @property
    def job_category(self):
        """Gets the job_category of this JobActivitiesData.  # noqa: E501

        Category of the job associated with the activity.  # noqa: E501

        :return: The job_category of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._job_category

    @job_category.setter
    def job_category(self, job_category):
        """Sets the job_category of this JobActivitiesData.

        Category of the job associated with the activity.  # noqa: E501

        :param job_category: The job_category of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._job_category = job_category

    @property
    def job_title(self):
        """Gets the job_title of this JobActivitiesData.  # noqa: E501

        Title of the job associated with the activity.  # noqa: E501

        :return: The job_title of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this JobActivitiesData.

        Title of the job associated with the activity.  # noqa: E501

        :param job_title: The job_title of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def site_type(self):
        """Gets the site_type of this JobActivitiesData.  # noqa: E501

        Type of site associated with the job.  # noqa: E501

        :return: The site_type of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this JobActivitiesData.

        Type of site associated with the job.  # noqa: E501

        :param site_type: The site_type of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._site_type = site_type

    @property
    def traffic_source_list(self):
        """Gets the traffic_source_list of this JobActivitiesData.  # noqa: E501

        List of traffic sources associated with the job.  # noqa: E501

        :return: The traffic_source_list of this JobActivitiesData.  # noqa: E501
        :rtype: list[JobActivitiesTrafficSourceList]
        """
        return self._traffic_source_list

    @traffic_source_list.setter
    def traffic_source_list(self, traffic_source_list):
        """Sets the traffic_source_list of this JobActivitiesData.

        List of traffic sources associated with the job.  # noqa: E501

        :param traffic_source_list: The traffic_source_list of this JobActivitiesData.  # noqa: E501
        :type: list[JobActivitiesTrafficSourceList]
        """

        self._traffic_source_list = traffic_source_list

    @property
    def job_location(self):
        """Gets the job_location of this JobActivitiesData.  # noqa: E501

        Location of the job.  # noqa: E501

        :return: The job_location of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._job_location

    @job_location.setter
    def job_location(self, job_location):
        """Sets the job_location of this JobActivitiesData.

        Location of the job.  # noqa: E501

        :param job_location: The job_location of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._job_location = job_location

    @property
    def updated_date(self):
        """Gets the updated_date of this JobActivitiesData.  # noqa: E501

        Date when the job activity was last updated.  # noqa: E501

        :return: The updated_date of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this JobActivitiesData.

        Date when the job activity was last updated.  # noqa: E501

        :param updated_date: The updated_date of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def field_id(self):
        """Gets the field_id of this JobActivitiesData.  # noqa: E501

        ID of the field associated with the job.  # noqa: E501

        :return: The field_id of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this JobActivitiesData.

        ID of the field associated with the job.  # noqa: E501

        :param field_id: The field_id of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def locale(self):
        """Gets the locale of this JobActivitiesData.  # noqa: E501

        Locale information associated with the job.  # noqa: E501

        :return: The locale of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this JobActivitiesData.

        Locale information associated with the job.  # noqa: E501

        :param locale: The locale of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def job_id(self):
        """Gets the job_id of this JobActivitiesData.  # noqa: E501

        ID of the job associated with the activity.  # noqa: E501

        :return: The job_id of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this JobActivitiesData.

        ID of the job associated with the activity.  # noqa: E501

        :param job_id: The job_id of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def action_type(self):
        """Gets the action_type of this JobActivitiesData.  # noqa: E501

        Type of action performed in the activity.  # noqa: E501

        :return: The action_type of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this JobActivitiesData.

        Type of action performed in the activity.  # noqa: E501

        :param action_type: The action_type of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._action_type = action_type

    @property
    def is_confidential(self):
        """Gets the is_confidential of this JobActivitiesData.  # noqa: E501

        Indicates whether the job is confidential.  # noqa: E501

        :return: The is_confidential of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._is_confidential

    @is_confidential.setter
    def is_confidential(self, is_confidential):
        """Sets the is_confidential of this JobActivitiesData.

        Indicates whether the job is confidential.  # noqa: E501

        :param is_confidential: The is_confidential of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._is_confidential = is_confidential

    @property
    def created_date(self):
        """Gets the created_date of this JobActivitiesData.  # noqa: E501

        Date when the job activity was created.  # noqa: E501

        :return: The created_date of this JobActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this JobActivitiesData.

        Date when the job activity was created.  # noqa: E501

        :param created_date: The created_date of this JobActivitiesData.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def traffic_sources(self):
        """Gets the traffic_sources of this JobActivitiesData.  # noqa: E501

        List of traffic sources associated with the job activity.  # noqa: E501

        :return: The traffic_sources of this JobActivitiesData.  # noqa: E501
        :rtype: list[JobActivitiesTrafficSourceList]
        """
        return self._traffic_sources

    @traffic_sources.setter
    def traffic_sources(self, traffic_sources):
        """Sets the traffic_sources of this JobActivitiesData.

        List of traffic sources associated with the job activity.  # noqa: E501

        :param traffic_sources: The traffic_sources of this JobActivitiesData.  # noqa: E501
        :type: list[JobActivitiesTrafficSourceList]
        """

        self._traffic_sources = traffic_sources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobActivitiesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobActivitiesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
